@@ -10,13 +10,13 @@ module Jekyll
 
       def render(context)
         site = context.registers[:site]
-        format = @format || site.config.dig('last-modified-at', 'date-format')
-        article_file = context.environments.first['page']['path']
+        format = @format || site.config.dig("last-modified-at", "date-format")
+        article_file = context.environments.first["page"]["path"]
         Determinator.new(site.source, article_file, format)
-                    .formatted_last_modified_date
+          .formatted_last_modified_date
       end
     end
   end
 end
 
-Liquid::Template.register_tag('last_modified_at', Jekyll::LastModifiedAt::Tag)
+Liquid::Template.register_tag("last_modified_at", Jekyll::LastModifiedAt::Tag)
